velruse — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- API Documentation »

# `velruse`

class `AuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  An AuthenticationComplete context object

class `AuthenticationDenied`(reason=None, provider_name=None, provider_type=None)

  An AuthenticationDenied context object. Used when the provider returned successfully but without proper credentials. This may be the case if the user cancels the login.

`login_url`(request, name)

  Generate the login URL for a provider.

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- API Documentation »